Learn R Programming

FoRDM (version 1.0.1)

fordm_analysis_satisficing: FoRDM Satisficing-Based many-objective Robust Decision-Making Analysis

Description

Performs a satisficing-based many-objective robustness analysis for the provided data and objectives, providing a optimal robust management and the Pareto front.

Usage

fordm_analysis_satisficing(fordm_table, objectives, robustness = 0.9)

Value

A list containing the FoRDM analysis results:

  • optimal: The management strategy that balances all objectives (Euclidean distance) while meeting the robustness threshold.

  • pareto_front: The Pareto front of robust management strategies.

Arguments

fordm_table

Output from build_fordm_table().

objectives

Output from build_objectives_satisficing().

robustness

Numeric (0-1) specifying the robustness level across SOWs, e.g., 0.9 evaluates management performance that meets objectives in at least 90% of SOWs.