Analyzes what happens when you sacrifice robustness for better performance. Shows marginal benefits and losses for each objective when switching between management strategies across different robustness levels.
robustness_tradeoff_analysis(fordm_table, objectives)List containing the list of optimal managements at certain robustness levels, and a plot
Output from build_FoRDM_table().
Output from build_objectives_regret().