Performs a regret-based (Type II or cVaR) many-objective robustness analysis for the provided data and objectives, providing a optimal robust management and the Pareto front.
fordm_analysis_regret(
fordm_table,
objectives,
robustness = 0.9,
method = "regretII"
)A list containing the results of the FoRDM analysis:
optimal: The management strategy identified as most robust given the regret metrics.
pareto_front: The Pareto front of robust management strategies.
Output from build_fordm_table().
Output from build_objectives_regret().
Numeric (0-1) specifying the quantile of regret used to define robustness, e.g., 0.9 evaluates management performance that is at least as good as in 90% of SOWs.
the method used to evaluate robustness
"regretII": Regret type II (regret to best performing alternative) approach using the robustness quantile of scenario regrets.
"CVaR": Conditional Value at Risk, using the mean of the worst (1 - robustness) fraction of weighted regrets for risk-aware selection.