Performs a satisficing-based many-objective robustness analysis for the provided data and objectives, providing a optimal robust management and the Pareto front.
fordm_analysis_satisficing(fordm_table, objectives, robustness = 0.9)A list containing the FoRDM analysis results:
optimal: The management strategy that balances all objectives (Euclidean distance) while meeting the robustness threshold.
pareto_front: The Pareto front of robust management strategies.
Output from build_fordm_table().
Output from build_objectives_satisficing().
Numeric (0-1) specifying the robustness level across SOWs, e.g., 0.9 evaluates management performance that meets objectives in at least 90% of SOWs.